Name: libmpfr
Version: 2.3.1
Release: alt1

Summary: Multiple Precision Floating-Point library
License: LGPLv2.1+
Group: System/Libraries
Url: http://www.mpfr.org/
Packager: Dmitry V. Levin <ldv@altlinux.org>

# Don't build static library by default
%def_disable static

BuildRequires: libgmp-devel

# http://www.mpfr.org/mpfr-current/mpfr-%version.tar.bz2
Source0: mpfr-%version.tar
Source1: mpfrxx.h

Patch: mpfr-%version-%release.patch

%package devel
Summary: Development MPFR library, header files and documentation
License: LGPLv2.1+, FDLv1.1+
Group: Development/C
Requires: %name = %version-%release
Requires: libgmp-devel
Conflicts: libgmp-devel = 0:4.1.4-alt3

%package devel-static
Summary: Static MPFR library
License: LGPLv2.1+
Group: Development/C
Requires: %name-devel = %version-%release

%description
MPFR provides a library for multiple-precision floating-point computation
with correct rounding.  The computation is both efficient and has a
well-defined semantics.  It copies the good ideas from the ANSI/IEEE-754
standard for double-precision floating-point arithmetic (53-bit mantissa).

%description devel
This package provides the header files and the symbolic links necessary
to allow compilation and linking of programs that use the libraries
provided in the %name package.

%description devel-static
This package provides static library necessary to allow static linking
of MPFR-based programs.

%prep
%setup -q -n mpfr-%version
%patch -p1
awk '/__MPFR_DECLSPEC/{decl=1}decl&&/_MPFR_PROTO/{decl=0;print}' mpfr.h |
	sed -n 's/^.*[[:space:]*]\+\([^[:space:]*]\+\)[[:space:]]\+_MPFR_PROTO.*/\1/p' |
	sort -u >libmpfr.sym
cat >>libmpfr.sym <<'EOF'
__gmpfr_cache_const_catalan
__gmpfr_cache_const_euler
__gmpfr_cache_const_log2
__gmpfr_cache_const_pi
__gmpfr_ceil_log2
__gmpfr_cuberoot
__gmpfr_default_fp_bit_precision
__gmpfr_default_rounding_mode
__gmpfr_emax
__gmpfr_emin
__gmpfr_flags
__gmpfr_floor_log2
__gmpfr_inp_str
__gmpfr_int_ceil_log2
__gmpfr_isqrt
__gmpfr_l2b
__gmpfr_mpfr_get_sj
__gmpfr_mpfr_get_uj
__gmpfr_out_str
__gmpfr_set_sj
__gmpfr_set_sj_2exp
__gmpfr_set_uj
__gmpfr_set_uj_2exp
mpfr_add1
mpfr_add1sp
mpfr_allocate_func
mpfr_assert_fail
mpfr_cache
mpfr_can_round_raw
mpfr_check
mpfr_clear_cache
mpfr_cmp2
mpfr_default_allocate
mpfr_default_free
mpfr_default_reallocate
mpfr_exp_2
mpfr_exp_3
mpfr_free_func
mpfr_init_gmp_rand
mpfr_nexttoinf
mpfr_nexttozero
mpfr_overflow
mpfr_powerof2_raw
mpfr_print_binary
mpfr_print_mant_binary
mpfr_rand_raw
mpfr_rands
mpfr_rands_initialized
mpfr_reallocate_func
mpfr_round_near_x
mpfr_round_p
mpfr_setmax
mpfr_setmin
mpfr_set_str_binary
mpfr_sub1
mpfr_sub1sp
mpfr_sum_sort
mpfr_tmp_allocate
mpfr_tmp_free
mpfr_underflow
EOF

%build
autoreconf -fisv
%configure --enable-shared %{subst_enable static}
%make_build
%{?!__buildreqs:%{?!_without_check:%{?!_disable_check:%make_build -k check}}}

%install
%makeinstall
install -pm644 %_sourcedir/mpfrxx.h %buildroot%_includedir/
%define docdir %_docdir/%name-%version
mkdir -p %buildroot%docdir
install -pm644 AUTHORS FAQ.html NEWS README TODO %buildroot%docdir/

%post -p %post_ldconfig
%postun -p %postun_ldconfig

%post devel
%install_info mpfr.info

%preun devel
%uninstall_info mpfr.info

%files
%_libdir/*.so.*
%docdir/[ANR]*

%files devel
%_libdir/*.so
%_includedir/*
%_infodir/*
%docdir/[FT]*

%if_enabled static
%files devel-static
%_libdir/*.a
%endif

%changelog
* Mon Mar 17 2008 Dmitry V. Levin <ldv@altlinux.org> 2.3.1-alt1
- Updated to 2.3.1.
- Restricted list of global symbols exported by the library to only those
  which are either declared in mpfr.h file or required by test suit.

* Tue Apr 10 2007 Dmitry V. Levin <ldv@altlinux.org> 2.2.1-alt1
- Updated to 2.2.1-p5.

* Sat Apr 22 2006 Dmitry V. Levin <ldv@altlinux.org> 2.2.0-alt1
- Packaged for Sisyphus.
